@@ -72,7 +72,7 @@ def _ports_lines():
 def _used_ports(lines):
     ports_mapping = dict()
 
-    listen_re = re.compile('^Listen localhost:\s*(?P<port>\d+)')
+    listen_re = re.compile('^Listen (?P<host>.+):\s*(?P<port>\d+)')
     instance_re = re.compile('^# used by (?P<instance>.+)')
 
     for index, line in enumerate(lines):
@@ -116,7 +116,7 @@ def _apache_setup_port():
             lines.extend([
                 '',
                 '# used by ' + env.conf.INSTANCE_NAME,
-                'Listen localhost:' + str(port)
+                'Listen 127.0.0.1:' + str(port)
             ])
             env.conf.APACHE_PORT = port
             puts('Instance is not binded to any port. Binding it to port ' + str(port))
