@@ -4,7 +4,7 @@ from fabric.api import *
 from fabric.contrib.console import confirm
 from fabric.contrib.files import upload_template
 
-from fab_deploy.utils import upload_config_template, delete_pyc, run_as
+from fab_deploy.utils import delete_pyc, run_as, detect_os
 from fab_deploy.virtualenv import pip_install, pip_update
 from fab_deploy.django_commands import compress, migrate, syncdb, test
 from fab_deploy.system import prepare_server
@@ -15,6 +15,9 @@ from fab_deploy import vcs
 
 def full_deploy():
     """ Prepares server and deploys the project. """
+    os = detect_os()
+    if not confirm("Is the OS detected correctly (%s)?" % os, default=False):
+        abort("Detection fails. Please set env.conf.OS to correct value.")
     prepare_server()
     deploy_project()
 
@@ -80,8 +83,8 @@ def push(*args):
     allowed_args = set(['force', 'notest', 'syncdb', 'migrate', 'pip_update', 'norestart'])
     for arg in args:
         if arg not in allowed_args:
-            print 'Invalid argument: %s' % arg
-            print 'Valid arguments are: %s' % allowed_args
+            puts('Invalid argument: %s' % arg)
+            puts('Valid arguments are: %s' % allowed_args)
             return
 
     vcs.push()
