@@ -1,10 +1,9 @@
 from datetime import datetime
 from fabric.api import *
-from fab_deploy.utils import run_as, inside_project, supports_only
+from fab_deploy.utils import run_as, inside_project, detect_os
 from fab_deploy.system import aptitude_install
 
 @run_as('root')
-@supports_only('lenny, squeeze')
 def mysql_install():
     """ Installs mysql. """
     if _mysql_is_installed():
@@ -13,16 +12,18 @@ def mysql_install():
 
     # this way mysql won't ask for a password on installation
     # see http://serverfault.com/questions/19367/scripted-install-of-mysql-on-ubuntu
+    os = detect_os()
     aptitude_install('debconf-utils')
     passwd=env.conf['DB_PASSWORD']
 
-    mysql_versions = {'lenny': '5.0', 'squeeze': '5.1'}
-    version = mysql_versions[env.conf.OS]
+    mysql_versions = {'lenny': '5.0', 'squeeze': '5.1', 'maverick': '5.1'}
+    version = mysql_versions[os]
 
     debconf_defaults = [
-        "mysql-server-%s\tmysql-server/root_password_again\tpassword\t%s" % (version, passwd),
-        "mysql-server-%s\tmysql-server/root_password\tpassword\t%s" % (version, passwd),
+        "mysql-server-%s mysql-server/root_password_again password %s" % (version, passwd),
+        "mysql-server-%s mysql-server/root_password password %s" % (version, passwd),
     ]
+
     run("echo '%s' | debconf-set-selections" % "\n".join(debconf_defaults))
 
     warn('\n=========\nThe password for mysql "root" user will be set to "%s"\n=========\n' % passwd)
@@ -48,7 +49,7 @@ def mysql_execute(sql, user=None, password=None):
     """ Executes passed sql command using mysql shell. """
     user = user or env.conf['DB_USER']
     password = env.conf['DB_PASSWORD'] if password is None else password
-    run ("echo '%s' | mysql -u%s -p%s" % (sql, user , password))
+    return run("echo '%s' | mysql -u%s -p%s" % (sql, user , password))
 
 def mysql_create_db():
     """ Creates an empty mysql database. """
