@@ -1,17 +1,14 @@
 from fabric.api import run, env, settings
-from fab_deploy.utils import run_as, upload_config_template, supports_only
+from fab_deploy.utils import run_as, upload_config_template, detect_os
 from fab_deploy.system import aptitude_install
 from fab_deploy.apache import _apache_setup_port
 
 @run_as('root')
-@supports_only('lenny, squeeze')
 def nginx_install():
     """ Installs nginx. """
-    options = {
-        'lenny': '-t lenny-backports',
-        'squeeze': '',
-    }
-    aptitude_install('nginx', options[env.conf.OS])
+    os = detect_os()
+    options = {'lenny': '-t lenny-backports'}
+    aptitude_install('nginx', options.get(os, ''))
     run('rm -f /etc/nginx/sites-enabled/default')
 
 @run_as('root')
