@@ -3,7 +3,8 @@ from __future__ import with_statement
 import os.path
 from fabric.api import run, settings, env, cd
 from fabric.contrib.files import append
-from fab_deploy.utils import run_as, supports_only
+from fab_deploy.utils import run_as, detect_os
+from fabric.utils import puts, abort
 
 def prepare_server():
     """ Prepares server: installs system packages. """
@@ -11,7 +12,6 @@ def prepare_server():
     install_common_software()
 
 @run_as('root')
-@supports_only('lenny, squeeze')
 def install_common_software():
     """ Installs common system packages. """
     common_packages = [
@@ -23,21 +23,22 @@ def install_common_software():
         'memcached',
         'subversion',
     ]
-
     extra_packages = {
         'lenny': ['libmysqlclient15-dev'],
         'squeeze': ['libmysqlclient-dev'],
+        'maverick': ['libmysqlclient-dev'],
     }
 
-    aptitude_install(" ".join(common_packages + extra_packages[env.conf.OS]))
+    os = detect_os()
+    if os not in extra_packages:
+        abort('Your OS (%s) is unsupported now.' % os)
+
+    aptitude_install(" ".join(common_packages + extra_packages[os]))
 
     # git and mercurial are outdated in stable Debian Lenny and
     # don't work with some source repositories on github and bitbucket
-    vcs_options = {
-        'lenny': '-t lenny-backports',
-        'squeeze': '',
-    }
-    aptitude_install('mercurial git', vcs_options[env.conf.OS])
+    vcs_options = {'lenny': '-t lenny-backports'}
+    aptitude_install('mercurial git', vcs_options.get(os, ""))
     aptitude_install('bzr', '--without-recommends')
 
     run('easy_install -U pip')
@@ -45,14 +46,19 @@ def install_common_software():
 
 
 @run_as('root')
-@supports_only('lenny, squeeze')
 def setup_backports():
     """ Adds backports repo to apt sources. """
+    os = detect_os()
     backports = {
         'lenny': 'http://backports.debian.org/debian-backports lenny-backports main contrib non-free',
         'squeeze': 'http://backports.debian.org/debian-backports squeeze-backports main contrib non-free',
     }
-    run("echo 'deb %s' > /etc/apt/sources.list.d/backports.sources.list" % backports[env.conf.OS])
+
+    if os not in backports:
+        puts("Backports are not available for " + os)
+        return
+
+    run("echo 'deb %s' > /etc/apt/sources.list.d/backports.sources.list" % backports[os])
     with settings(warn_only=True):
         run('aptitude update')
 
@@ -73,6 +79,7 @@ def ssh_add_key(pub_key_file):
     """ Adds a ssh key from passed file to user's authorized_keys on server. """
     with open(os.path.normpath(pub_key_file), 'rt') as f:
         ssh_key = f.read()
+    run('mkdir -p .ssh')
     append('.ssh/authorized_keys', ssh_key)
 
 
