@@ -1,12 +1,29 @@
 import os
 import pprint
+from re import match
 from functools import wraps
 from fabric.contrib.files import upload_template
 from fabric.api import *
 from fabric.state import _AttributeDict
 from fabric.network import normalize, join_host_strings
 
-SUPPORTED_SYSTEMS = ['lenny', 'squeeze']
+def _codename(distname, version, id):
+    patterns = [
+        ('lenny', ('debian', '^5', '')),
+        ('squeeze', ('debian', '^6', '')),
+        ('maverick', ('Ubuntu', '^10.10', '')),
+    ]
+    for name, p in patterns:
+        if match(p[0], distname) and match(p[1], version) and match(p[2], id):
+            return name
+
+def detect_os():
+    if 'conf' in env and 'OS' in env.conf:
+        return env.conf['OS']
+    output = run('python -c "import platform; print platform.dist()"')
+    name = _codename(*eval(output))
+    puts('%s detected' % name)
+    return name
 
 def run_as(user):
     """
@@ -32,28 +49,6 @@ def run_as(user):
         return inner
     return decorator
 
-def supports_only(supported_systems):
-    """ Safety decorator. Marks command as only supported for a set of
-    operating systems. Aborts execution if :attr:`env.conf.OS` is not in
-    list. Accepts string with comma-separated list of system names::
-
-        @supports_only('lenny, squeeze')
-        def my_command():
-            pass
-
-    """
-    systems = [s.strip().lower() for s in supported_systems.split(',')]
-    def decorator(func):
-        @wraps(func)
-        def inner(*args, **kwargs):
-            if env.conf.OS not in systems:
-                abort('%s is not supported. Supported operating systems: %s' % (
-                    env.conf.OS, supported_systems))
-            return func(*args, **kwargs)
-        return inner
-    return decorator
-
-
 def upload_config_template(name, to=None):
     if to is None:
         base_dir = env.conf['ENV_DIR'] + "/etc/"
@@ -83,6 +78,8 @@ def update_env():
     assert len(env.hosts)==1, "Multiple hosts in env.hosts are not supported now. (%s)" % env.hosts
     user, host, port = normalize(env.hosts[0])
 
+    env.conf = getattr(env, 'conf', {})
+
     HOME_DIR = '/home/%s' % user
     if 'INSTANCE_NAME' not in env.conf:
         env.conf['INSTANCE_NAME'] = user
@@ -95,7 +92,6 @@ def update_env():
         THREADS = 15,
         SERVER_NAME = host,
         SERVER_ADMIN = 'example@example.com',
-        OS = 'lenny',
         VCS = 'hg',
 
         # these options shouldn't be set by user
@@ -111,10 +107,6 @@ def update_env():
         if env.conf.VCS == vcs:
             env.conf.VCS = 'fab_deploy.vcs.'+vcs
 
-    if env.conf.OS not in SUPPORTED_SYSTEMS:
-        abort('%s is not supported. Supported operating systems: %s' % (
-            env.conf.OS, ', '.join(SUPPORTED_SYSTEMS)
-        ))
 
 def virtualenv():
     """
