@@ -1,6 +1,6 @@
-from fabric.api import run, env, cd, env, prefix
+from fabric.api import run, env, cd
 from fab_deploy.apache import touch
-from fab_deploy.utils import run_as, inside_project
+from fab_deploy.utils import inside_project
 
 @inside_project
 def pip(commands=''):
